@@ -3,70 +3,20 @@ from pydantic import BaseModel, Field, validator, root_validator, constr, conlis
 from typing import List, Union
 from enum import Enum
 
-from ._base import IDdBaseModel, NoExtraBaseModel
+from ._base import IDdBaseModel
 from .boundarycondition import Outdoors, Surface, Ground, Adiabatic
+
 from .energy.properties import ShadeEnergyPropertiesAbridged, \
     DoorEnergyPropertiesAbridged, ApertureEnergyPropertiesAbridged, \
     FaceEnergyPropertiesAbridged, RoomEnergyPropertiesAbridged, \
     ModelEnergyProperties
+
 from .radiance.properties import ShadeRadiancePropertiesAbridged, \
     DoorRadiancePropertiesAbridged, ApertureRadiancePropertiesAbridged, \
     FaceRadiancePropertiesAbridged, RoomRadiancePropertiesAbridged, \
     ModelRadianceProperties
 
-
-class Plane(NoExtraBaseModel):
-
-    type: constr(regex='^Plane$') = 'Plane'
-
-    n: List[float] = Field(
-        ...,
-        description="Plane normal as 3 (x, y, z) values.",
-        min_items=3,
-        max_items=3
-    )
-
-    o: List[float] = Field(
-        ...,
-        description="Plane origin as 3 (x, y, z) values",
-        min_items=3,
-        max_items=3
-    )
-
-    x: List[float] = Field(
-        default=None,
-        description="Plane x-axis as 3 (x, y, z) values. If None, it is autocalculated.",
-        min_items=3,
-        max_items=3
-    )
-
-
-class Face3D(NoExtraBaseModel):
-    """A single planar face in 3D space."""
-
-    type: constr(regex='^Face3D$') = 'Face3D'
-
-    boundary: List[conlist(float, min_items=3, max_items=3)] = Field(
-        ...,
-        min_items=3,
-        description='A list of points representing the outer boundary vertices of '
-            'the face. The list should include at least 3 points and each point '
-            'should be a list of 3 (x, y, z) values.'
-    )
-
-    holes: List[conlist(conlist(float, min_items=3, max_items=3), min_items=3)] = Field(
-        default=None,
-        description='Optional list of lists with one list for each hole in the face.'
-            'Each hole should be a list of at least 3 points and each point a list '
-            'of 3 (x, y, z) values. If None, it will be assumed that there are no '
-            'holes in the face.'
-    )
-
-    plane: Plane = Field(
-        default=None,
-        description='Optional Plane indicating the plane in which the face exists.'
-            'If None, the plane will usually be derived from the boundary points.'
-    )
+from .geometry import Plane, Face3D
 
 
 class ShadePropertiesAbridged(BaseModel):
@@ -123,7 +73,7 @@ class Door(IDdBaseModel):
     boundary_condition: Union[Outdoors, Surface]
 
     @validator('boundary_condition')
-    def suface_bc_objects(cls, v):
+    def surface_bc_objects(cls, v):
         if v.type == 'Surface':
             assert len(v.boundary_condition_objects) == 3, 'Door Surface boundary ' \
                 'condition must have 3 boundary_condition_objects.'
@@ -178,7 +128,7 @@ class Aperture(IDdBaseModel):
     boundary_condition: Union[Outdoors, Surface]
 
     @validator('boundary_condition')
-    def suface_bc_objects(cls, v):
+    def surface_bc_objects(cls, v):
         if v.type == 'Surface':
             assert len(v.boundary_condition_objects) == 3, 'Aperture Surface boundary ' \
                 'condition must have 3 boundary_condition_objects.'
@@ -243,7 +193,7 @@ class Face(IDdBaseModel):
     boundary_condition: Union[Ground, Outdoors, Adiabatic, Surface]
 
     @validator('boundary_condition')
-    def suface_bc_objects(cls, v):
+    def surface_bc_objects(cls, v):
         if v.type == 'Surface':
             assert len(v.boundary_condition_objects) == 2, 'Face Surface boundary ' \
                 'condition must have 2 boundary_condition_objects.'
@@ -279,12 +229,12 @@ class Face(IDdBaseModel):
     )
 
     @root_validator
-    def chack_air_boundarys_are_interior(cls, values):
+    def check_air_boundaries_are_interior(cls, values):
         """Check that all air wall faces have a Surface boundary condition."""
         face_type, bc = values.get('face_type'), values.get('boundary_condition')
         if face_type == 'AirBoundary':
             assert bc.type == 'Surface', \
-                'AirBoundarys must have "Surface" boundary conditions.'
+                'AirBoundaries must have "Surface" boundary conditions.'
         return values
 
 
@@ -395,13 +345,6 @@ class Model(IDdBaseModel):
             'to be exported for energy simulation.'
     )
 
-    north_angle: float = Field(
-        default=0,
-        ge=0,
-        lt=360,
-        description='The clockwise north direction in degrees.'
-    )
-
     units: Units = Field(
         default=Units.meters,
         description='Text indicating the units in which the model geometry exists. '
@@ -419,7 +362,7 @@ class Model(IDdBaseModel):
             'in no attempt to evaluate whether Room volumes are closed or check '
             'face direction. So it is recommended that this always be a positive '
             'number when such checks have not been performed on a Model. '
-            'Typical tolerances for builing geometry range from 0.1 to 0.0001 '
+            'Typical tolerances for building geometry range from 0.1 to 0.0001 '
             'depending on the units of the geometry.'
     )
 
@@ -433,7 +376,7 @@ class Model(IDdBaseModel):
             'in no attempt to evaluate whether the Room volumes is closed or check '
             'face direction. So it is recommended that this always be a positive '
             'number when such checks have not been performed on a given Model. '
-            'Typical tolerances for builing geometry are often around 1 degree.'
+            'Typical tolerances for building geometry are often around 1 degree.'
     )
 
     properties: ModelProperties = Field(
@@ -441,7 +384,3 @@ class Model(IDdBaseModel):
         description='Extension properties for particular simulation engines '
             '(Radiance, EnergyPlus).'
     )
-
-
-if __name__ == '__main__':
-    print(Model.schema_json(indent=2))
